==> haskell-doclayout-0.4.0.1-29-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doclayout
version:              0.4.0.1
visibility:           public
id:                   doclayout-0.4.0.1-46hZ9EdFXbJ1TXJggbU79
key:                  doclayout-0.4.0.1-46hZ9EdFXbJ1TXJggbU79
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doclayout
synopsis:             A prettyprinting library for laying out text documents.
description:
    doclayout is a prettyprinting library for laying out
    text documents, with several features not present
    in prettyprinting libraries designed for code.  It
    was designed for use in pandoc.

category:             Text
abi:                  edffb989210be05aabeccd93db07684a
exposed:              True
exposed-modules:      Text.DocLayout
import-dirs:          /usr/lib/ghc-9.2.8/site-local/doclayout-0.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doclayout-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doclayout
hs-libraries:         HSdoclayout-0.4.0.1-46hZ9EdFXbJ1TXJggbU79
depends:
    base-4.16.4.0 containers-0.6.5.1
    emojis-0.1.3-2fWN4o25Br14sN86enRfw1 mtl-2.2.2
    safe-0.3.21-iv9yHEgDynJNZkwcC9KXL text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-doclayout/html/doclayout.haddock
haddock-html:         /usr/share/doc/haskell-doclayout/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doclayout-0.4.0.1-31-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doclayout
version:              0.4.0.1
visibility:           public
id:                   doclayout-0.4.0.1-IxeDl9AwMnpIQPfei6hK0V
key:                  doclayout-0.4.0.1-IxeDl9AwMnpIQPfei6hK0V
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doclayout
synopsis:             A prettyprinting library for laying out text documents.
description:
    doclayout is a prettyprinting library for laying out
    text documents, with several features not present
    in prettyprinting libraries designed for code.  It
    was designed for use in pandoc.

category:             Text
abi:                  f9b1d4f4e4579f07a995bcefb662bb1d
exposed:              True
exposed-modules:      Text.DocLayout
import-dirs:          /usr/lib/ghc-9.2.8/site-local/doclayout-0.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doclayout-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doclayout
hs-libraries:         HSdoclayout-0.4.0.1-IxeDl9AwMnpIQPfei6hK0V
depends:
    base-4.16.4.0 containers-0.6.5.1
    emojis-0.1.3-7lp6bSa8ElkLZwS3L5NWjG mtl-2.2.2
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-doclayout/html/doclayout.haddock
haddock-html:         /usr/share/doc/haskell-doclayout/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
